﻿Type.registerNamespace("Dowds.Gadgets");

Dowds.Gadgets.Gadget = function()
{
    Dowds.Gadgets.Gadget.initializeBase(this);
    
    this._dataLoaded = false;
    this._dataNotAvailable = false;
    
    this._dataLoadedDisplayDiv = null;
    this._dataLoadingDisplayDiv = null;
    this._dataNotAvailableDisplayDiv = null;

    this._dataDisplayDivs = [];
};

Dowds.Gadgets.Gadget.prototype = 
{
    initialize: function()
    {
        // Hookup to the gadget API
        System.Gadget.onDock = Function.createDelegate(this, this._updateDisplay);
        System.Gadget.onUndock = Function.createDelegate(this, this._updateDisplay);
        System.Gadget.settingsUI = "Settings.html";
        System.Gadget.onSettingsClosed = Function.createDelegate(this, this._settingsClosed);

        // Get a reference to all of the different display divs
        this._dataLoadedDisplayDiv = $get("dataLoadedDisplay");
        this._dataLoadingDisplayDiv = $get("dataLoadingDisplay");
        this._dataNotAvailableDisplayDiv = $get("dataNotAvailableDisplay");
        this._dataDisplayDivs = 
        [
            this._dataLoadedDisplayDiv, 
            this._dataLoadingDisplayDiv, 
            this._dataNotAvailableDisplayDiv
        ];

        Dowds.Gadgets.Gadget.callBaseMethod(this, 'initialize');
    },

    _settingsClosed: Function.emptyFunction,

    _updateDisplay: function()
    {
        this._hideAllDisplays();
        this._getCurrentDisplayDiv().style.visibility = "visible";
    },

    _getCurrentDisplayDiv: function()
    {
        if(this._dataNotAvailable)
        {
            return this._dataNotAvailableDisplayDiv;
        }
        else
        {
            return (this._dataLoaded) ? this._dataLoadedDisplayDiv : this._dataLoadingDisplayDiv;
        }
    },

    _hideAllDisplays: function()
    {
        for(var i=0; i<this._dataDisplayDivs.length; i++)
        {
            this._dataDisplayDivs[i].style.visibility = "hidden";
        }
    }
};

Dowds.Gadgets.Gadget.registerClass("Dowds.Gadgets.Gadget", Sys.Component);