﻿Type.registerNamespace("Dowds.Gadgets");

Dowds.Gadgets.MovieInfo = function(rssItemNode)
{
    Dowds.Gadgets.MovieInfo.initializeBase(this);
    
    this._rssItemNode = rssItemNode;    
    this._title = this._readTitleValue();
    this._link = this._readValue("link");
    this._description = this._readValue("description");
    this._percent = this._readPercentValue();
    this._rating = this._readValue("RTmovie:tomatometer_rating") || "N\\A";
    this._fresh = this._readValue("RTmovie:certified_fresh");
};

Dowds.Gadgets.MovieInfo.prototype = 
{
    get_title: function() { return this._title; },

    get_link: function() { return this._link; },

    get_description: function() { return this._description; },

    get_percent: function() { return this._percent; },

    get_rating: function() { return this._rating; },

    get_fresh: function() { return this._fresh; },

    _readTitleValue: function()
    {
        var title = this._readValue("title");
        // keep only what comes after the percent sign
        return title.substring(title.indexOf("% ") + 1, title.length);
    },

    _readPercentValue: function()
    {
        var percent = parseInt(this._readValue("RTmovie:tomatometer_percent"));
        if(percent)
        {
            // pad the value and give it a percent sign
            return (percent < 10) ? ("0" + percent + "%") : (percent + "%"); 
        }
        else
        {
            return "-";
        }
    },

    _readValue: function(childElementName)
    {
        var node = this._rssItemNode.getElementsByTagName(childElementName)[0].firstChild;
        if(node != null)
        {
            return node.nodeValue;
        }
        return null;
    },

    get_displayColor: function(darkBackground)
    {
        if(this._fresh == "1")              return (darkBackground) ? "#FF9" : "#870";
        else if (this._rating == "Fresh")   return  (darkBackground) ?"#9C9" : "#060";
        else if (this._rating == "Rotten")  return (darkBackground) ? "#F99" : "#900";
        else                                return (darkBackground) ? "#FFF" : "#000";
    },
    
    get_tooltip: function()
    {
        var prefix = (this.get_fresh() == "1") ? "Certified " : "";
        var tooltip = this.get_percent() + " (" + prefix + this.get_rating() + ") - " + this.get_title();
        return tooltip;
    }
};

Dowds.Gadgets.MovieInfo.ParseFromDoc = function(xmlDoc)
{
    var movies = [];
    var rssItemNodes = xmlDoc.getElementsByTagName("item");

    for(var i=0; i<rssItemNodes.length; i++)
    {
        movies.push(new Dowds.Gadgets.MovieInfo(rssItemNodes[i]));
    }
    
    return movies;
};

Dowds.Gadgets.MovieInfo.registerClass("Dowds.Gadgets.MovieInfo");