Type.registerNamespace("Dowds.Gadgets");

Dowds.Gadgets.Movies = function() 
{
    Dowds.Gadgets.Movies.initializeBase(this);

    this._data = null;
    this._selectedMovieInfo = null;
};

Dowds.Gadgets.Movies.prototype = 
{
    initialize: function()
    {
        Dowds.Gadgets.Movies.callBaseMethod(this, "initialize");

        System.Gadget.Flyout.file = "Flyout.html";
        System.Gadget.Flyout.onShow = Function.createDelegate(this, this._updateFlyout);
        // Close the flyout when the body is clicked
        $addHandler(document.body, "click", Function.createDelegate(this, this._body_onclick));

        this._requestData();
    },
    
    _requestData: function()
    {
        var wRequest = new Sys.Net.WebRequest();
        wRequest.set_url(this._getDataSourceUrl());
        wRequest.add_completed(Function.createDelegate(this, this._processData));
        wRequest.invoke();
    },

    _processData: function(executor)
    {
        if (executor.get_responseAvailable() && executor.get_xml() != null) 
        {
            var movieDoc = executor.get_xml();


            this._dataLoaded = true;
            this._dataNotAvailable = false;

            this._data = Dowds.Gadgets.MovieInfo.ParseFromDoc(movieDoc);
            this._bindTable(this._data);
        }
        else
        {
            this._dataLoaded = false;
            this._dataNotAvailable = true;
        }

        // Refresh the data in 1 hour
        setTimeout(Function.createDelegate(this, this._requestData), (4 * 3600000));

        this._updateDisplay();
    },

    _getDataSourceUrl: function()
    {
        var defaultDataSourceUrl = "http://i.rottentomatoes.com/syndication/rss/top_movies.xml";
        var settingsDataSourceUrl = System.Gadget.Settings.readString("DataSourceUrl");
        return (settingsDataSourceUrl || defaultDataSourceUrl);
    },

    _getDataSourceName: function()
    {
        var defaultValue = "TOP MOVIES";
        var settingsValue = System.Gadget.Settings.readString("DataSourceName");
        return (settingsValue || defaultValue);
    },

    _settingsClosed: function()
    {
        this._clearData();
        this._updateDisplay();
        this._requestData();
    },

    _updateDisplay: function()
    {
        this._updateTitle();
        Dowds.Gadgets.Movies.callBaseMethod(this, '_updateDisplay')
    },

    _updateTitle: function()
    {
        $get("title").innerText = this._getDataSourceName();
    },

    _clearData: function()
    {
        this._data = null;
        this._dataLoaded = false;
        this._dataNotAvailable = false;
        this._updateDisplay();
    },

    _bindTable: function(movies)
    {
        var table = document.getElementsByTagName("table")[0];
        var rows = table.rows;
        for(var i=0; i<rows.length && i<movies.length; i++)
        {
            var movie = movies[i];

            var row = rows[i];
            var percentCell = row.cells[0];
            var titleCell = row.cells[1];

            row.title = movie.get_tooltip();

            percentCell.innerText = movie.get_percent();
            percentCell.style.color = movie.get_displayColor(true);

            var link = titleCell.firstChild.firstChild;
            link.innerText = movie.get_title();
            link.movieInfo = movie;

            $addHandler(link, "click", Function.createDelegate(this, this._link_onclick));
        }
    },

    _link_onclick: function(e)
    {
        this._selectedMovieInfo = e.target.movieInfo;
        if(System.Gadget.Flyout.show)
        {
            this._updateFlyout();
        }
        else
        {
            System.Gadget.Flyout.show = true;
        }
        e.stopPropagation();
    },

    _body_onclick: function()
    {
            System.Gadget.Flyout.show = false;
    },

    _updateFlyout: function()
    {
        var flyoutWindow = System.Gadget.Flyout.document.parentWindow;
        flyoutWindow.moviesFlyout.reload(this._selectedMovieInfo);
    }
};

Dowds.Gadgets.Movies.registerClass("Dowds.Gadgets.Movies", Dowds.Gadgets.Gadget);

//////////////////////////////////////////////////////

var moviesGadget;
window.onload = function()
{
    moviesGadget = $create(Dowds.Gadgets.Movies);
};